@@ -592,69 +592,14 @@ sub SetCookie
 	$ENV{'HTTP_COOKIE'} .= "$name=$value";
 }
 ###########################################
-sub ReadConfig 
-{
-	my $self = $0;
-	$self =~ s/\.\w+$/.conf/;
-	my @conf = ($self, "/etc/merge.conf", &GetHome . "/.merge");
-
-	foreach my $f (@conf) 
-	{
-        	if (open(CFG, $f))
-	 	{
-			no strict;
-			my $code = join("", <CFG>);
-			close(CFG);
-			eval $code;
-			if ($@) 
-			{
-				print "Status: 501 Server error\n";
-				print "Content-type: text/plain\n\n";
-				print "$f caused error: $@";
-				exit;
-			}
-
-			$HTML::Merge::config = $f;
-        	        last;
-	        }
-	}
-
-	$self =~ s/\.\w+$/.ext/;
-	foreach my $ext (($self, "/etc/merge.ext")) 
-	{
-		if (-f $self) 
-		{
-			package HTML::Merge::Ext;
-			eval 'require $self;';
-			if ($@) 
-			{
-				print "Status: 501 Server error\n";
-				print "Content-type: text/plain\n\n";
-				print "$self caused error: $@";
-				exit;
-			}
-		}
-	}
-}
-###############################################################################
-sub GetHome 
-{
-	return if ($^O =~ /Win/);
-
-	my ($name,$passwd,$uid,$gid,
-        $quota,$comment,$gcos,$dir,$shell,$expire) = getpwuid($>);
-
-	return $dir;
-}
-###############################################################################
-sub import 
-{
-	my (@param) = @_;
-
-	return if ($param[1] eq ':unconfig');
-
-	&ReadConfig;
-}
+#sub import 
+#{
+#	my (@param) = @_;
+#
+#	return if ($param[1] eq ':unconfig');
+#
+#	&ReadConfig;
+#}
 ###########################################
 sub Convert 
 {
